@@ -7,9 +7,7 @@
 
 package button_box;
 
-use constant FALSE => 0;
-use constant TRUE => 1;
-
+use Glib qw(TRUE FALSE);
 use Gtk2;
 
 sub create_bbox {
