@@ -7,9 +7,7 @@
 
 package dialog;
 
-use constant FALSE => 0;
-use constant TRUE => 1;
-
+use Glib qw(TRUE FALSE);
 use Gtk2;
 
 my $window = undef;
